# blempy — Blender ↔ NumPy helpers

[![GitHub Release](https://img.shields.io/github/v/release/varkenvarken/blempy?include_prereleases&logo=github)](https://github.com/varkenvarken/blempy)


`blempy` provides small, safe utilities to efficiently transfer Blender property-collection attributes (e.g. vertex coordinates) to/from NumPy arrays and perform vectorized operations with minimal Python overhead.

More information on [the website](https://varkenvarken.github.io/blempy/) accompanying the repo.
